# Policy module for UiO
#
# Relevant Documentation:
#
#   - SELinux Policy Modules Packaging Draft:
#           http://fedoraproject.org/wiki/PackagingDrafts/SELinux/PolicyModules
#
#   - Packaging:ScriptletSnippets
#           http://fedoraproject.org/wiki/Packaging/ScriptletSnippets
#

# SELinux stuff
%global selinux_variants targeted
%global selinux_policyver %(%{__sed} -e 's,.*selinux-policy-\\([^/]*\\)/.*,\\1,' /usr/share/selinux/devel/policyhelp || echo 0.0.0)

# Home root dirs
%global uio_homeroot_dirs /admin /use /usit /med /odont /mn /hf /sv /jus /rh /tf /div /ub /uv /ifi /uio

# CFEngine bin dir
%global cfengine_bindir /var/cfengine/bin

# Policy name
%global module uio

Name:       uio-selinux
Version:    9.12
Release:    1%{?dist}
Summary:    SELinux policy for UiO

Group:      System Environment/Base
License:    GPLv3+

URL:        http://www.uio.no/tjenester/it/maskin/linux/
Source0:    uio.fc
Source1:    uio.if
Source2:    uio.te

BuildArch:        noarch
BuildRequires:    selinux-policy-devel hardlink checkpolicy
Requires:         selinux-policy >= %{selinux_policyver}
Requires(post):   /usr/sbin/semodule /sbin/fixfiles /sbin/restorecon
Requires(preun):  /usr/sbin/semodule /sbin/fixfiles
Requires(postun): /usr/sbin/semodule /sbin/restorecon

# This package replaces uio-selinux-policy
Provides:      uio-selinux-policy = %{version}-%{release}
Obsoletes:     uio-selinux-policy <= 1.0.12

%description
This package contains SELinux policies for UiO. The policies are for
other packages built and maintained for UiO.

%prep
%setup -q -c -T
install -p -m 644 %{SOURCE0} .
install -p -m 644 %{SOURCE1} .
install -p -m 644 %{SOURCE2} .


%build
# Build the selinux policy file
for variant in %{selinux_variants}
do
    make NAME=${variant} -f %{_datadir}/selinux/devel/Makefile
    mv %{module}.pp %{module}.pp.${variant}
    make NAME=${variant} -f %{_datadir}/selinux/devel/Makefile clean
done


%install
# Install selinux policies
for variant in %{selinux_variants}; do
    install -d -m 0755 %{buildroot}%{_sysconfdir}/selinux/${variant}/modules/active/modules
    install -p -m 0644 %{module}.pp.${variant} \
           %{buildroot}%{_sysconfdir}/selinux/${variant}/modules/active/modules/%{module}.pp
done


%post
# Install SELinux policy modules
for variant in %{selinux_variants}; do
    semodule --store ${variant} --install \
      %{_sysconfdir}/selinux/${variant}/modules/active/modules/%{module}.pp &> /dev/null || :
done

# Fixing files in own package
fixfiles -R %{name} restore || :

# Fixing files in CFEngine binaries dir
[ -d %{cfengine_bindir} ] && \
  restorecon -R %{cfengine_bindir} &> /dev/null || :

# Fixing UiO home root dirs
for dir in %{uio_homeroot_dirs}; do
    [ -d ${dir} ] && restorecon ${dir} &> /dev/null || :
done

# Fixing legacy stuff
[ -d /local ] && restorecon -R /local &> /dev/null || :


%preun
# package un-install
if [ "$1" -lt "1" ] ; then
    for variant in %{selinux_variants}; do
        semodule --store ${variant} --remove %{module} &> /dev/null || :
    done
fi
fixfiles -R %{name} restore || :


%postun
# package upgrade
if [ "$1" -ge "1" ] ; then
    # Replace the module if it is already loaded. semodule -u also
    # checks the module version
    for variant in %{selinux_variants}; do
        semodule --install %{_sysconfdir}/selinux/${variant}/modules/active/modules/%{module}.pp || :
    done

    # Fixing files in CFEngine binaries dir
    [ -d %{cfengine_bindir} ] && \
      restorecon -R %{cfengine_bindir} &> /dev/null || :

    # Fixing UiO home root dirs
    for dir in %{uio_homeroot_dirs}; do
        [ -d ${dir} ] && restorecon ${dir} &> /dev/null || :
    done

    # Fixing legacy stuff
    [ -d /local ] && restorecon -R /local &> /dev/null || :
fi


%files
%defattr(-,root,root,-)
%doc %{module}.{te,fc,if}
%{_sysconfdir}/selinux/*/modules/active/modules/%{module}.pp


%changelog
* Tue Jun 14 2022 Trond Hasle Amundsen <trondham@uio.no> - 9.12-1
- Add rules for falco service

* Tue Nov 16 2021 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 9.11-1
- Allow Zabbix agent to monitor PostgreSQL through UNIX sockets - additions (RT#4639247)

* Fri Oct  1 2021 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 9.10-1
- Allow Zabbix agent to monitor PostgreSQL through UNIX sockets (RT#4572477)

* Tue Sep  7 2021 Trond Hasle Amundsen <trondham@uio.no> - 9.9-2
- Allow systemd remove_name access on the directory of cf-execd.pid
- Allow systemd unlink access on the file cf-execd.pid

* Fri Dec 18 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 9.8-1
- Add Collectd rules for EL8 (RT##4187555 ny selinux policy for collectd)

* Mon Nov  9 2020 Trond Hasle Amundsen <trondham@uio.no> - 9.7-1
- Allow dhcpd name_bind access on the port 519 tcp_socket

* Wed Oct 21 2020 Trond Hasle Amundsen <trondham@uio.no> - 9.6-1
- Allow dhcpd name_bind access on the port 520 tcp_socket

* Mon Aug 31 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 9.5-2
- Add RHEL 8 rules for www

* Fri Jun 26 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 9.5-1
- Allow Zabbix agent to open and read files in /var/lib/zabbix

* Mon Jun 22 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 9.4-1
- Allow Zabbix agent to create temporary files in /tmp

* Tue Jan 14 2020 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 9.3-1
- Allow vmtools_unconfined_t process transition to rpm_script_t

* Mon Dec 16 2019 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 9.2-1
- Change to shell_exec_t for symlinks to shells under /local

* Wed Dec 04 2019 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 9.1-1
- RT#3671189: selinux policy oppdatering for memcached overvåking via Zabbix

* Mon Sep 23 2019 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 9.0-1
- Initial build for RHEL8
